import { dataSource } from "../data-source";
import { reset } from "../entity/reset";
import InternalException from "../exceptions/internalException";

export default abstract class ResetService {
  /**
   * @description get reset by id
   * @param mail string
   * @param token string
   * @returns {Promise<reset>}
   */
  static async getByMailAndToken(mail: string, token: string): Promise<reset> {
    return await dataSource
      .getRepository(reset)
      .createQueryBuilder("reset")
      .where("reset.mail = :mail", { mail: mail })
      .andWhere("reset.token = :token", { token: token })
      .getOneOrFail()
      .then((res) => {
        return res;
      })
      .catch((err) => {
        throw new InternalException("reset not found by mail and token", err);
      });
  }
}
